@@ -25,6 +25,7 @@ scorematrix = function (X) {
   
   ### SCORE MATRIX OF RANK DATA ACCORDING EMOND AND MASON
   
+  itemnames=names(X)
   if (is.numeric(X) & !is.matrix(X)){
     X=matrix(X,ncol=length(X))
   }
@@ -33,6 +34,8 @@ scorematrix = function (X) {
   
   #X must be a row vector containing a ranking of m objects
   sm=matrix(0,c,c)
+  colnames(sm)=itemnames
+  row.names(sm)=itemnames
   
   for (j in 1:c){
     diffs=sign(X[j]-X[setdiff(1:c,j)])
